# Automatically generated by get_definitionsALL.sql from database PRJ_TDCFDOKU.GRIB_PARAMETER@OFC1MIR.DWD.DE, do not edit! 2025-10-01 06:15
#paramId: 500000
#Pressure (S) (not reduced)
'Pressure (S) (not reduced)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500001
#Pressure
'Pressure' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500002
#Pressure Reduced to MSL
'Pressure Reduced to MSL' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500003
#Pressure Tendency (S)
'Pressure Tendency (S)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 3 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500004
#Geopotential (S)
'Geopotential (S)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500005
#Geopotential (full lev)
'Geopotential (full lev)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	 indicatorOfTypeOfLevel = 110 ;
	}

#paramId: 500006
#Geopotential
'Geopotential' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500007
#Geometric Height of the earths surface above sea level
'Geometric Height of the earths surface above sea level' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500008
#Geometric Height of the layer limits above sea level(NN)
'Geometric Height of the layer limits above sea level(NN)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	 indicatorOfTypeOfLevel = 109 ;
	}

#paramId: 500009
#Total Column Integrated Ozone
'Total Column Integrated Ozone' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500010
#Temperature (G)
'Temperature (G)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500011
#2m Temperature
'2m Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500012
#2m Temperature (AV)
'2m Temperature (AV)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 3 ;
	 level = 2 ;
	}

#paramId: 500013
#Climat. temperature, 2m Temperature
'Climat. temperature, 2m Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 3 ;
	 level = 2 ;
	}

#paramId: 500014
#Temperature
'Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500015
#Max 2m Temperature (i)
'Max 2m Temperature (i)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500016
#Min 2m Temperature (i)
'Min 2m Temperature (i)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500017
#2m Dew Point Temperature
'2m Dew Point Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500018
#2m Dew Point Temperature (AV)
'2m Dew Point Temperature (AV)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 3 ;
	 level = 2 ;
	}

#paramId: 500019
#Radar spectra (1)
'Radar spectra (1)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 500020
#Wave spectra (1)
'Wave spectra (1)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 500021
#Wave spectra (2)
'Wave spectra (2)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500022
#Wave spectra (3)
'Wave spectra (3)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500023
#Wind Direction (DD_10M)
'Wind Direction (DD_10M)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500024
#Wind Direction (DD)
'Wind Direction (DD)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500025
#Wind speed (SP_10M)
'Wind speed (SP_10M)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500026
#Wind speed (SP)
'Wind speed (SP)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500027
#U-Component of Wind
'U-Component of Wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500028
#U-Component of Wind
'U-Component of Wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500029
#V-Component of Wind
'V-Component of Wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500030
#V-Component of Wind
'V-Component of Wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500031
#Vertical Velocity (Pressure) ( omega=dp/dt )
'Vertical Velocity (Pressure) ( omega=dp/dt )' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 500032
#Vertical Velocity (Geometric) (w)
'Vertical Velocity (Geometric) (w)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500034
#Specific Humidity (2m)
'Specific Humidity (2m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500035
#Specific Humidity
'Specific Humidity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 500036
#2m Relative Humidity
'2m Relative Humidity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500037
#Relative Humidity
'Relative Humidity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 500038
#Total column integrated water vapour
'Total column integrated water vapour' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 500039
#Evaporation (s)
'Evaporation (s)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500040
#Total Column-Integrated Cloud Ice
'Total Column-Integrated Cloud Ice' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 58 ;
	}

#paramId: 500041
#Total Precipitation (Accumulation)
'Total Precipitation (Accumulation)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500042
#Large-Scale Precipitation (Accumulation)
'Large-Scale Precipitation (Accumulation)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 62 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 500043
#Convective Precipitation (Accumulation)
'Convective Precipitation (Accumulation)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 500044
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 500045
#Snow Depth
'Snow Depth' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 500046
#Total Cloud Cover
'Total Cloud Cover' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500047
#Convective Cloud Cover
'Convective Cloud Cover' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500048
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500049
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500050
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500051
#Total Column-Integrated Cloud Water
'Total Column-Integrated Cloud Water' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 500052
#Convective Snowfall water equivalent (s)
'Convective Snowfall water equivalent (s)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 500053
#Large-Scale snowfall - water equivalent (Accumulation)
'Large-Scale snowfall - water equivalent (Accumulation)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500054
#Land Cover (1=land, 0=sea)
'Land Cover (1=land, 0=sea)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 500055
#Surface Roughness length Surface Roughness
'Surface Roughness length Surface Roughness' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 500056
#Albedo (in short-wave)
'Albedo (in short-wave)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 500057
#Albedo (in short-wave, average)
'Albedo (in short-wave, average)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500058
#Soil Temperature  ( 36 cm depth, vv=0h)
'Soil Temperature  ( 36 cm depth, vv=0h)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 36 ;
	}

#paramId: 500059
#Soil Temperature (41 cm depth)
'Soil Temperature (41 cm depth)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 41 ;
	}

#paramId: 500060
#Soil Temperature
'Soil Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 9 ;
	}

#paramId: 500061
#Soil Temperature
'Soil Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500062
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 100 ;
	 bottomLevel = 190 ;
	}

#paramId: 500063
#Column-integrated Soil Moisture (1) 0 -10 cm
'Column-integrated Soil Moisture (1) 0 -10 cm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 10 ;
	}

#paramId: 500064
#Column-integrated Soil Moisture (2) 10-100cm
'Column-integrated Soil Moisture (2) 10-100cm' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 10 ;
	 bottomLevel = 100 ;
	}

#paramId: 500065
#Plant cover
'Plant cover' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 500066
#Water Runoff
'Water Runoff' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 topLevel = 10 ;
	}

#paramId: 500068
#Water Runoff (s)
'Water Runoff (s)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	 topLevel = 0 ;
	}

#paramId: 500069
#Sea Ice Cover ( 0= free, 1=cover)
'Sea Ice Cover ( 0= free, 1=cover)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500070
#Sea Ice Thickness
'Sea Ice Thickness' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500071
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500072
#Direction of wind waves
'Direction of wind waves' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500073
#Significant height of wind waves
'Significant height of wind waves' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 500074
#Mean period of wind waves
'Mean period of wind waves' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 500075
#Mean direction of total swell
'Mean direction of total swell' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 500076
#Significant height of total swell
'Significant height of total swell' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500077
#Mean period of total swell
'Mean period of total swell' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 500078
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500079
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500080
#Net long wave radiation flux (m) (at the surface)
'Net long wave radiation flux (m) (at the surface)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500081
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500082
#Net short wave radiation flux (on the model top)
'Net short wave radiation flux (on the model top)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500083
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	}

#paramId: 500084
#Net long wave radiation flux (m) (on the model top)
'Net long wave radiation flux (m) (on the model top)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500085
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	}

#paramId: 500086
#Latent Heat Net Flux (m)
'Latent Heat Net Flux (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500087
#Sensible Heat Net Flux (m)
'Sensible Heat Net Flux (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500088
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500089
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500090
#Photosynthetically active radiation (m) (at the surface)
'Photosynthetically active radiation (m) (at the surface)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500091
#Photosynthetically active radiation
'Photosynthetically active radiation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500092
#Solar radiation heating rate
'Solar radiation heating rate' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500093
#Thermal radiation heating rate
'Thermal radiation heating rate' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500094
#Latent heat flux from bare soil
'Latent heat flux from bare soil' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 18 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500095
#Latent heat flux from plants
'Latent heat flux from plants' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 19 ;
	 indicatorOfTypeOfLevel = 111 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500096
#Sunshine duration in h
'Sunshine duration in h' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 20 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 500097
#Stomatal Resistance
'Stomatal Resistance' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 21 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500098
#Cloud cover
'Cloud cover' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500099
#Non-Convective Cloud Cover, grid scale
'Non-Convective Cloud Cover, grid scale' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500100
#Cloud Mixing Ratio
'Cloud Mixing Ratio' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500101
#Cloud Ice Mixing Ratio
'Cloud Ice Mixing Ratio' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500102
#Rain mixing ratio
'Rain mixing ratio' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 500103
#Snow mixing ratio
'Snow mixing ratio' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 500104
#Total column integrated rain
'Total column integrated rain' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 500105
#Total column integrated snow
'Total column integrated snow' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 500106
#Grauple
'Grauple' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 500107
#Total column integrated grauple
'Total column integrated grauple' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500108
#Total Column integrated water (all components incl. precipitation)
'Total Column integrated water (all components incl. precipitation)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500109
#vertical integral of divergence of total water content (s)
'vertical integral of divergence of total water content (s)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 500110
#subgrid scale cloud water
'subgrid scale cloud water' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500111
#subgridscale cloud ice
'subgridscale cloud ice' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500112
#cloud cover CH (0..8)
'cloud cover CH (0..8)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 500113
#cloud cover CM (0..8)
'cloud cover CM (0..8)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 500114
#cloud cover CL (0..8)
'cloud cover CL (0..8)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 500115
#cloud base above msl, shallow convection
'cloud base above msl, shallow convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 58 ;
	 indicatorOfTypeOfLevel = 2 ;
	}

#paramId: 500116
#Cloud top above msl, shallow convection
'Cloud top above msl, shallow convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 59 ;
	 indicatorOfTypeOfLevel = 3 ;
	}

#paramId: 500117
#specific cloud water content, convective cloud
'specific cloud water content, convective cloud' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500118
#Height of Convective Cloud Base above msl
'Height of Convective Cloud Base above msl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 68 ;
	 indicatorOfTypeOfLevel = 2 ;
	}

#paramId: 500119
#Height of Convective Cloud Top above msl
'Height of Convective Cloud Top above msl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 69 ;
	 indicatorOfTypeOfLevel = 3 ;
	}

#paramId: 500120
#base index (vertical level) of main convective cloud (i)
'base index (vertical level) of main convective cloud (i)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 72 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500121
#top index (vertical level) of main convective cloud (i)
'top index (vertical level) of main convective cloud (i)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500122
#Temperature tendency due to convection
'Temperature tendency due to convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500123
#Specific humidity tendency due to convection
'Specific humidity tendency due to convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500124
#zonal wind tendency due to convection
'zonal wind tendency due to convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 500125
#meridional wind tendency due to convection
'meridional wind tendency due to convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500126
#Height of top of dry convection above MSL
'Height of top of dry convection above MSL' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 82 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500127
#Height of 0 degree Celsius isotherm above msl
'Height of 0 degree Celsius isotherm above msl' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 84 ;
	 indicatorOfTypeOfLevel = 4 ;
	}

#paramId: 500128
#Height of snow fall limit above MSL
'Height of snow fall limit above MSL' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 4 ;
	}

#paramId: 500129
#Tendency of specific cloud liquid water content due to convection
'Tendency of specific cloud liquid water content due to convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 500130
#tendency of  specific cloud ice content due to convection
'tendency of  specific cloud ice content due to convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 500131
#Specific content of precipitation particles (needed for water loading)
'Specific content of precipitation particles (needed for water loading)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500132
#Large scale rain rate
'Large scale rain rate' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500133
#Large scale snowfall rate water equivalent
'Large scale snowfall rate water equivalent' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500134
#Large scale rain (Accumulation)
'Large scale rain (Accumulation)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 500135
#Convective rain rate
'Convective rain rate' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 500136
#Convective snowfall rate water equivalent
'Convective snowfall rate water equivalent' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 500137
#Convective rain
'Convective rain' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500138
#rain amount, grid-scale plus convective
'rain amount, grid-scale plus convective' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 500139
#snow amount, grid-scale plus convective
'snow amount, grid-scale plus convective' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500140
#Temperature tendency due to grid scale precipation
'Temperature tendency due to grid scale precipation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 500141
#Specific humidity tendency due to grid scale precipitation
'Specific humidity tendency due to grid scale precipitation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 500142
#tendency of specific cloud liquid water content due to grid scale precipitation
'tendency of specific cloud liquid water content due to grid scale precipitation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 500143
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'Fresh snow factor (weighting function for albedo indicating freshness of snow)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 129 ;
	}

#paramId: 500144
#tendency of specific cloud ice content due to grid scale precipitation
'tendency of specific cloud ice content due to grid scale precipitation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 130 ;
	}

#paramId: 500145
#Graupel (snow pellets) precipitation rate
'Graupel (snow pellets) precipitation rate' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 131 ;
	}

#paramId: 500146
#Graupel (snow pellets) precipitation (Accumulation)
'Graupel (snow pellets) precipitation (Accumulation)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500147
#Snow density
'Snow density' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 133 ;
	}

#paramId: 500148
#Pressure perturbation
'Pressure perturbation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 139 ;
	}

#paramId: 500149
#supercell detection index 1 (rot. up+down drafts)
'supercell detection index 1 (rot. up+down drafts)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 141 ;
	}

#paramId: 500150
#supercell detection index 2 (only rot. up drafts)
'supercell detection index 2 (only rot. up drafts)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 142 ;
	}

#paramId: 500151
#Convective Available Potential Energy, most unstable
'Convective Available Potential Energy, most unstable' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 143 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500152
#Convective Inhibition, most unstable
'Convective Inhibition, most unstable' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 144 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500153
#Convective Available Potential Energy, mean layer
'Convective Available Potential Energy, mean layer' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 145 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500154
#Convective Inhibition, mean layer
'Convective Inhibition, mean layer' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 146 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500155
#Convective turbulent kinetic enery
'Convective turbulent kinetic enery' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 147 ;
	}

#paramId: 500156
#Tendency of turbulent kinetic energy
'Tendency of turbulent kinetic energy' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 148 ;
	}

#paramId: 500157
#Kinetic Energy
'Kinetic Energy' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 149 ;
	}

#paramId: 500158
#Turbulent Kinetic Energy
'Turbulent Kinetic Energy' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 152 ;
	}

#paramId: 500159
#Turbulent diffusioncoefficient for momentum
'Turbulent diffusioncoefficient for momentum' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 153 ;
	}

#paramId: 500160
#Turbulent diffusion coefficient for heat (and moisture)
'Turbulent diffusion coefficient for heat (and moisture)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 154 ;
	}

#paramId: 500161
#Turbulent transfer coefficient for impulse
'Turbulent transfer coefficient for impulse' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 170 ;
	}

#paramId: 500162
#Turbulent transfer coefficient for heat (and Moisture)
'Turbulent transfer coefficient for heat (and Moisture)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 171 ;
	}

#paramId: 500163
#mixed layer depth
'mixed layer depth' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 173 ;
	}

#paramId: 500164
#maximum Wind 10m
'maximum Wind 10m' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500166
#Soil Temperature (multilayer model)
'Soil Temperature (multilayer model)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 197 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500167
#Column-integrated Soil Moisture (multilayers)
'Column-integrated Soil Moisture (multilayers)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 198 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500168
#soil ice content (multilayers)
'soil ice content (multilayers)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 199 ;
	 indicatorOfTypeOfLevel = 111 ;
	}

#paramId: 500169
#Plant Canopy Surface Water
'Plant Canopy Surface Water' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 200 ;
	}

#paramId: 500170
#Snow temperature (top of snow)
'Snow temperature (top of snow)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500171
#Minimal Stomatal Resistance
'Minimal Stomatal Resistance' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500172
#Sea Ice Temperature
'Sea Ice Temperature' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 215 ;
	}

#paramId: 500173
#Base reflectivity
'Base reflectivity' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500174
#Base reflectivity
'Base reflectivity' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 110 ;
	}

#paramId: 500175
#Base reflectivity (cmax)
'Base reflectivity (cmax)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	}

#paramId: 500176
#solution of 2-d Helmholtz equations - needed for restart
'solution of 2-d Helmholtz equations - needed for restart' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500177
#Effective transmissivity of solar radiation
'Effective transmissivity of solar radiation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 233 ;
	}

#paramId: 500178
#sum of contributions to evaporation
'sum of contributions to evaporation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 236 ;
	}

#paramId: 500179
#total transpiration from all soil layers
'total transpiration from all soil layers' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 237 ;
	}

#paramId: 500180
#total forcing at soil surface
'total forcing at soil surface' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 238 ;
	}

#paramId: 500181
#residuum of soil moisture
'residuum of soil moisture' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 239 ;
	}

#paramId: 500182
#Massflux at convective cloud base
'Massflux at convective cloud base' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 240 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500183
#Convective Available Potential Energy
'Convective Available Potential Energy' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 241 ;
	}

#paramId: 500184
#moisture convergence for Kuo-type closure
'moisture convergence for Kuo-type closure' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 243 ;
	}

#paramId: 500185
#Total Wave Direction
'Total Wave Direction' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500187
#Peak period of total swell
'Peak period of total swell' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500189
#Swell peak period
'Swell peak period' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500190
#Total wave peak period
'Total wave peak period' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500191
#Total wave mean period
'Total wave mean period' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500192
#Total Tm1 period
'Total Tm1 period' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500193
#Total Tm2 period
'Total Tm2 period' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 500194
#Total directional spread
'Total directional spread' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500195
#analysis error(standard deviation), geopotential(gpm)
'analysis error(standard deviation), geopotential(gpm)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500196
#analysis error(standard deviation), u-comp. of wind
'analysis error(standard deviation), u-comp. of wind' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500197
#analysis error(standard deviation), v-comp. of wind
'analysis error(standard deviation), v-comp. of wind' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 500198
#zonal wind tendency due to subgrid scale oro.
'zonal wind tendency due to subgrid scale oro.' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500199
#meridional wind tendency due to subgrid scale oro.
'meridional wind tendency due to subgrid scale oro.' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 500200
#Standard deviation of sub-grid scale orography
'Standard deviation of sub-grid scale orography' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 500201
#Anisotropy of sub-gridscale orography
'Anisotropy of sub-gridscale orography' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 500202
#Angle of sub-gridscale orography
'Angle of sub-gridscale orography' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 500203
#Slope of sub-gridscale orography
'Slope of sub-gridscale orography' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 500204
#surface emissivity
'surface emissivity' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 500205
#soil type of grid (1...9, local soilType.table)
'soil type of grid (1...9, local soilType.table)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 500206
#Leaf area index
'Leaf area index' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500207
#root depth of vegetation
'root depth of vegetation' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 500208
#height of ozone maximum (climatological)
'height of ozone maximum (climatological)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 500209
#vertically integrated ozone content (climatological)
'vertically integrated ozone content (climatological)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 500210
#Plant covering degree in the vegetation phase
'Plant covering degree in the vegetation phase' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 500211
#Plant covering degree in the quiescent phas
'Plant covering degree in the quiescent phas' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 500212
#Max Leaf area index
'Max Leaf area index' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 500213
#Min Leaf area index
'Min Leaf area index' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500214
#Orographie + Land-Meer-Verteilung
'Orographie + Land-Meer-Verteilung' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500215
#variance of soil moisture content (0-10)
'variance of soil moisture content (0-10)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	}

#paramId: 500216
#variance of soil moisture content (10-100)
'variance of soil moisture content (10-100)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 112 ;
	}

#paramId: 500217
#evergreen forest
'evergreen forest' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500218
#deciduous forest
'deciduous forest' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 500219
#normalized differential vegetation index
'normalized differential vegetation index' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 77 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500220
#normalized differential vegetation index (NDVI)
'normalized differential vegetation index (NDVI)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500221
#ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500222
#current ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'current ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500223
#Total sulfate aerosol
'Total sulfate aerosol' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 500224
#Total sulfate aerosol (12M)
'Total sulfate aerosol (12M)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 84 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500225
#Total soil dust aerosol (climatology)
'Total soil dust aerosol (climatology)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 500226
#Total soil dust aerosol (climatology,12M)
'Total soil dust aerosol (climatology,12M)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 86 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500227
#Organic aerosol
'Organic aerosol' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500228
#Organic aerosol (12M)
'Organic aerosol (12M)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 91 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500229
#Black carbon aerosol
'Black carbon aerosol' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500230
#Black carbon aerosol (12M)
'Black carbon aerosol (12M)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 92 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500231
#Sea salt aerosol
'Sea salt aerosol' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500232
#Sea salt aerosol (12M)
'Sea salt aerosol (12M)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 93 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500233
#tendency of specific humidity
'tendency of specific humidity' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 500234
#water vapor flux
'water vapor flux' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500235
#Coriolis parameter
'Coriolis parameter' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500236
#geographical latitude
'geographical latitude' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 500237
#geographical longitude
'geographical longitude' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 500239
#Delay of the GPS signal trough the (total) atm.
'Delay of the GPS signal trough the (total) atm.' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 500240
#Delay of the GPS signal trough wet atmos.
'Delay of the GPS signal trough wet atmos.' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 500241
#Delay of the GPS signal trough dry atmos.
'Delay of the GPS signal trough dry atmos.' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500242
#Ozone Mixing Ratio
'Ozone Mixing Ratio' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 180 ;
	}

#paramId: 500243
#Air concentration of Ruthenium 103
'Air concentration of Ruthenium 103' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500244
#Ru103 - dry deposition
'Ru103 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 195 ;
	}

#paramId: 500245
#Ru103 - wet deposition
'Ru103 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 500246
#Air concentration of Strontium 90
'Air concentration of Strontium 90' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 197 ;
	}

#paramId: 500247
#Sr90 - dry deposition
'Sr90 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 198 ;
	}

#paramId: 500248
#Sr90 - wet deposition
'Sr90 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 199 ;
	}

#paramId: 500249
#Air concentration of Iodine 131 aerosol
'Air concentration of Iodine 131 aerosol' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 200 ;
	}

#paramId: 500250
#I131 - dry deposition
'I131 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 201 ;
	}

#paramId: 500251
#I131 - wet deposition
'I131 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 202 ;
	}

#paramId: 500252
#Air concentration of Caesium 137
'Air concentration of Caesium 137' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500253
#Cs137 - dry deposition
'Cs137 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 204 ;
	}

#paramId: 500255
#Air concentration of Tellurium 132
'Air concentration of Tellurium 132' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 206 ;
	}

#paramId: 500256
#Te132 - dry deposition
'Te132 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 207 ;
	}

#paramId: 500257
#Te132 - wet deposition
'Te132 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 208 ;
	}

#paramId: 500258
#Air concentration of Zirconium 95
'Air concentration of Zirconium 95' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 209 ;
	}

#paramId: 500259
#Zr95 - dry deposition
'Zr95 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 210 ;
	}

#paramId: 500260
#Zr95 - wet deposition
'Zr95 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 211 ;
	}

#paramId: 500261
#Air concentration of Krypton 85
'Air concentration of Krypton 85' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500262
#Kr85 - dry deposition
'Kr85 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 213 ;
	}

#paramId: 500263
#Kr85 - wet deposition
'Kr85 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 214 ;
	}

#paramId: 500264
#TRACER - concentration
'TRACER - concentration' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 215 ;
	}

#paramId: 500265
#TRACER - dry deposition
'TRACER - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 216 ;
	}

#paramId: 500266
#TRACER - wet deposition
'TRACER - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 217 ;
	}

#paramId: 500267
#Air concentration of Xenon 133
'Air concentration of Xenon 133' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 218 ;
	}

#paramId: 500268
#Xe133 - dry deposition
'Xe133 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 219 ;
	}

#paramId: 500269
#Xe133 - wet deposition
'Xe133 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 220 ;
	}

#paramId: 500270
#Air concentration of Iodine 131 elementary gaseous
'Air concentration of Iodine 131 elementary gaseous' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 221 ;
	}

#paramId: 500271
#I131g - dry deposition
'I131g - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 222 ;
	}

#paramId: 500272
#I131g - wet deposition
'I131g - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 223 ;
	}

#paramId: 500273
#Air concentration of Iodine 131 organic bounded
'Air concentration of Iodine 131 organic bounded' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 224 ;
	}

#paramId: 500274
#I131o - dry deposition
'I131o - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 225 ;
	}

#paramId: 500275
#I131o - wet deposition
'I131o - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 226 ;
	}

#paramId: 500276
#Air concentration of Barium 140
'Air concentration of Barium 140' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 227 ;
	}

#paramId: 500277
#Ba140 - dry deposition
'Ba140 - dry deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 228 ;
	}

#paramId: 500278
#Ba140 - wet deposition
'Ba140 - wet deposition' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 229 ;
	}

#paramId: 500279
#u-momentum flux due to SSO-effects
'u-momentum flux due to SSO-effects' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500280
#u-momentum flux due to SSO-effects
'u-momentum flux due to SSO-effects' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	}

#paramId: 500281
#v-momentum flux due to SSO-effects (average)
'v-momentum flux due to SSO-effects (average)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500282
#v-momentum flux due to SSO-effects
'v-momentum flux due to SSO-effects' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500283
#Gravity wave dissipation (initialisation)
'Gravity wave dissipation (initialisation)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500284
#Gravity wave dissipation (vertical integral)
'Gravity wave dissipation (vertical integral)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	}

#paramId: 500285
#UV Index, clouded sky, maximum
'UV Index, clouded sky, maximum' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 248 ;
	}

#paramId: 500286
#Vertical speed shear
'Vertical speed shear' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500287
#storm relative helicity
'storm relative helicity' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500288
#Absolute vorticity advection
'Absolute vorticity advection' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500289
#Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ,tab)
'Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ,tab)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 500290
#Hoehe der Konvektionsuntergrenze ueber Grund
'Hoehe der Konvektionsuntergrenze ueber Grund' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 91 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500291
#Hoehe der Konvektionsuntergrenze ueber nn
'Hoehe der Konvektionsuntergrenze ueber nn' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 94 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500292
#weather interpretation (WMO)
'weather interpretation (WMO)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500293
#geostrophische Vorticityadvektion
'geostrophische Vorticityadvektion' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500294
#geostrophische Schichtdickenadvektion
'geostrophische Schichtdickenadvektion' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 500295
#Schichtdickenadvektion
'Schichtdickenadvektion' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 107 ;
	}

#paramId: 500296
#Winddivergenz
'Winddivergenz' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 500297
#Q-Vektor senkrecht zu den Isothermen
'Q-Vektor senkrecht zu den Isothermen' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 500298
#Isentrope potentielle Vorticity
'Isentrope potentielle Vorticity' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 130 ;
	 indicatorOfTypeOfLevel = 100 ;
	}

#paramId: 500299
#Wind X-Komponente auf isentropen Flaechen
'Wind X-Komponente auf isentropen Flaechen' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 131 ;
	}

#paramId: 500300
#Wind Y-Komponente auf isentropen Flaechen
'Wind Y-Komponente auf isentropen Flaechen' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500301
#Druck einer isentropen Flaeche
'Druck einer isentropen Flaeche' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 133 ;
	 indicatorOfTypeOfLevel = 100 ;
	}

#paramId: 500302
#KO index
'KO index' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 140 ;
	}

#paramId: 500303
#Aequivalentpotentielle Temperatur
'Aequivalentpotentielle Temperatur' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 154 ;
	}

#paramId: 500304
#Ceiling
'Ceiling' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 157 ;
	}

#paramId: 500305
#Icing Grade (1=LGT,2=MOD,3=SEV)
'Icing Grade (1=LGT,2=MOD,3=SEV)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 500306
#modified cloud depth for media
'modified cloud depth for media' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500307
#modified cloud cover for media
'modified cloud cover for media' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 204 ;
	}

#paramId: 500308
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500309
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500310
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'Monthly Mean of RMS of difference FG-AN of u-component of wind' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500311
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'Monthly Mean of RMS of difference IA-AN of u-component of wind' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500312
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'Monthly Mean of RMS of difference FG-AN of v-component of wind' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500313
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'Monthly Mean of RMS of difference IA-AN of v-component of wind' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500314
#Monthly Mean of RMS of difference FG-AN of geopotential
'Monthly Mean of RMS of difference FG-AN of geopotential' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500315
#Monthly Mean of RMS of difference IA-AN of geopotential
'Monthly Mean of RMS of difference IA-AN of geopotential' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500316
#Monthly Mean of RMS of difference FG-AN of relative humidity
'Monthly Mean of RMS of difference FG-AN of relative humidity' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500317
#Monthly Mean of RMS of difference IA-AN of relative humidity
'Monthly Mean of RMS of difference IA-AN of relative humidity' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500318
#Monthly Mean of RMS of difference FG-AN of temperature
'Monthly Mean of RMS of difference FG-AN of temperature' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500319
#Monthly Mean of RMS of difference IA-AN of temperature
'Monthly Mean of RMS of difference IA-AN of temperature' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 500320
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500321
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500322
#Monthly Mean of RMS of difference FG-AN of kinetic energy
'Monthly Mean of RMS of difference FG-AN of kinetic energy' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 500323
#Monthly Mean of RMS of difference IA-AN of kinetic energy
'Monthly Mean of RMS of difference IA-AN of kinetic energy' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 500324
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500325
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500326
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500327
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 1 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500328
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500329
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500330
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500331
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 2 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	}

#paramId: 500332
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500333
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500334
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500335
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500336
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500337
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500338
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500339
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 3 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500340
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500341
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500342
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500343
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500344
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500345
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500346
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500347
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 1 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500348
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500349
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500350
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500351
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500352
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500353
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500354
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500355
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500356
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500357
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500358
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500359
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500360
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500361
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500362
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500363
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 3 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500364
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 6 ;
	}

#paramId: 500365
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 7 ;
	}

#paramId: 500366
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 8 ;
	}

#paramId: 500367
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 1 ;
	}

#paramId: 500368
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 4 ;
	}

#paramId: 500369
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 5 ;
	}

#paramId: 500370
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 2 ;
	}

#paramId: 500371
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 table2Version = 205 ;
	 indicatorOfParameter = 4 ;
	 localElementNumber = 4 ;
	 indicatorOfTypeOfLevel = 222 ;
	 level = 3 ;
	}

#paramId: 500372
#smoothed forecast, temperature
'smoothed forecast, temperature' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500373
#smoothed forecast, maximum temp.
'smoothed forecast, maximum temp.' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500374
#smoothed forecast, minimum temp.
'smoothed forecast, minimum temp.' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500375
#smoothed forecast, dew point temp.
'smoothed forecast, dew point temp.' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 17 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 500376
#smoothed forecast, u comp. of wind
'smoothed forecast, u comp. of wind' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500377
#smoothed forecast, v comp. of wind
'smoothed forecast, v comp. of wind' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500378
#smoothed forecast, total precipitation (Accumulation)
'smoothed forecast, total precipitation (Accumulation)' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500379
#smoothed forecast, total cloud cover
'smoothed forecast, total cloud cover' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500380
#smoothed forecast, cloud cover low
'smoothed forecast, cloud cover low' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 73 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500381
#smoothed forecast, cloud cover medium
'smoothed forecast, cloud cover medium' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 74 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500382
#smoothed forecast, cloud cover high
'smoothed forecast, cloud cover high' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 75 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 500383
#smoothed forecast, large-scale snowfall
'smoothed forecast, large-scale snowfall' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500384
#smoothed forecast, soil temperature
'smoothed forecast, soil temperature' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 111 ;
	 level = 0 ;
	}

#paramId: 500385
#smoothed forecast, wind speed (gust)
'smoothed forecast, wind speed (gust)' = {
	 table2Version = 206 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500386
#calibrated forecast, total precipitation  (Accumulation)
'calibrated forecast, total precipitation  (Accumulation)' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500387
#calibrated forecast, large-scale snowfall
'calibrated forecast, large-scale snowfall' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500388
#calibrated forecast, wind speed (gust)
'calibrated forecast, wind speed (gust)' = {
	 table2Version = 207 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 500401
#Total Precipitation Difference
'Total Precipitation Difference' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 timeRangeIndicator = 5 ;
	}

#paramId: 500402
#Max 2m Temperature long periods > h
'Max 2m Temperature long periods > h' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 55 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500403
#Min 2m Temperature long periods > h
'Min 2m Temperature long periods > h' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 56 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 2 ;
	 level = 2 ;
	}

#paramId: 500404
#Total Precipitation (Accumulation) Initialisation
'Total Precipitation (Accumulation) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500408
#Large scale rain (Accumulation) Initialisation
'Large scale rain (Accumulation) Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500409
#Large-Scale snowfall - water equivalent (Accumulation) Initialisation
'Large-Scale snowfall - water equivalent (Accumulation) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500410
#Convective rain Initialisation
'Convective rain Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500411
#Convective Snowfall water equivalent (s) Initialisation
'Convective Snowfall water equivalent (s) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500412
#maximum Wind 10m Initialisation
'maximum Wind 10m Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 187 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 0 ;
	 level = 10 ;
	}

#paramId: 500416
#Evaporation (s) Initialisation
'Evaporation (s) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500417
#Max 2m Temperature (i) Initialisation
'Max 2m Temperature (i) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 0 ;
	 level = 2 ;
	}

#paramId: 500418
#Min 2m Temperature (i) Initialisation
'Min 2m Temperature (i) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 0 ;
	 level = 2 ;
	}

#paramId: 500419
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500420
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	 indicatorOfTypeOfLevel = 8 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500421
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500422
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500423
#Large-Scale snowfall - water equivalent (Accumulation) Initialisation
'Large-Scale snowfall - water equivalent (Accumulation) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 79 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500424
#Convective Snowfall water equivalent (s) Initialisation
'Convective Snowfall water equivalent (s) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 78 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500425
#Total Precipitation (Accumulation) Initialisation
'Total Precipitation (Accumulation) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 61 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500428
#Latent Heat Net Flux (m) Initialisation
'Latent Heat Net Flux (m) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500429
#Sensible Heat Net Flux (m) Initialisation
'Sensible Heat Net Flux (m) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500430
#Momentum Flux, U-Component (m) Initialisation
'Momentum Flux, U-Component (m) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500431
#Momentum Flux, V-Component (m) Initialisation
'Momentum Flux, V-Component (m) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500432
#Photosynthetically active radiation
'Photosynthetically active radiation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 5 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500433
#Large scale rain (Accumulation) Initialisation
'Large scale rain (Accumulation) Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 102 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500434
#Convective rain Initialisation
'Convective rain Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 113 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500436
#Graupel (snow pellets) precipitation (Initialisation)
'Graupel (snow pellets) precipitation (Initialisation)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 132 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500437
#Probability of 1h total precipitation >= 10mm
'Probability of 1h total precipitation >= 10mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500438
#Probability of 1h total precipitation >= 25mm
'Probability of 1h total precipitation >= 25mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500439
#Probability of 6h total precipitation >= 20mm
'Probability of 6h total precipitation >= 20mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500440
#Probability of 6h total precipitation >= 35mm
'Probability of 6h total precipitation >= 35mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500441
#Probability of 12h total precipitation >= 25mm
'Probability of 12h total precipitation >= 25mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 500442
#Probability of 12h total precipitation >= 40mm
'Probability of 12h total precipitation >= 40mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500443
#Probability of 12h total precipitation >= 70mm
'Probability of 12h total precipitation >= 70mm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500444
#Probability of 6h accumulated snow >=0.5cm
'Probability of 6h accumulated snow >=0.5cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 500445
#Probability of 6h accumulated snow >= 5cm
'Probability of 6h accumulated snow >= 5cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500446
#Probability of 6h accumulated snow >= 10cm
'Probability of 6h accumulated snow >= 10cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500447
#Probability of 12h accumulated snow >=0.5cm
'Probability of 12h accumulated snow >=0.5cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500448
#Probability of 12h accumulated snow >= 10cm
'Probability of 12h accumulated snow >= 10cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500449
#Probability of 12h accumulated snow >= 15cm
'Probability of 12h accumulated snow >= 15cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500450
#Probability of 12h accumulated snow >= 25cm
'Probability of 12h accumulated snow >= 25cm' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 500451
#Probability of 1h maximum wind gust speed >= 14m/s
'Probability of 1h maximum wind gust speed >= 14m/s' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500452
#Probability of 1h maximum wind gust speed >= 18m/s
'Probability of 1h maximum wind gust speed >= 18m/s' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 134 ;
	}

#paramId: 500453
#Probability of 1h maximum wind gust speed >= 25m/s
'Probability of 1h maximum wind gust speed >= 25m/s' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 136 ;
	}

#paramId: 500454
#Probability of 1h maximum wind gust speed >= 29m/s
'Probability of 1h maximum wind gust speed >= 29m/s' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 137 ;
	}

#paramId: 500455
#Probability of 1h maximum wind gust speed >= 33m/s
'Probability of 1h maximum wind gust speed >= 33m/s' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 138 ;
	}

#paramId: 500456
#Probability of 1h maximum wind gust speed >= 39m/s
'Probability of 1h maximum wind gust speed >= 39m/s' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 139 ;
	}

#paramId: 500457
#Probability of black ice during 1h
'Probability of black ice during 1h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500458
#Probability of thunderstorm during 1h
'Probability of thunderstorm during 1h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 197 ;
	}

#paramId: 500459
#Probability of heavy thunderstorm during 1h
'Probability of heavy thunderstorm during 1h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 198 ;
	}

#paramId: 500460
#Probability of severe thunderstorm during 1h
'Probability of severe thunderstorm during 1h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 199 ;
	}

#paramId: 500461
#Probability of snowdrift during 12h
'Probability of snowdrift during 12h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500462
#Probability of strong snowdrift during 12h
'Probability of strong snowdrift during 12h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 213 ;
	}

#paramId: 500463
#Probability of temperature < 0 deg C during 1h
'Probability of temperature < 0 deg C during 1h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500464
#Probability of temperature <= -10 deg C during 6h
'Probability of temperature <= -10 deg C during 6h' = {
	 table2Version = 208 ;
	 indicatorOfParameter = 236 ;
	}

#paramId: 500465
#UV Index, clear sky; corrected for albedo, aerosol and altitude
'UV Index, clear sky; corrected for albedo, aerosol and altitude' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 240 ;
	}

#paramId: 500466
#Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol
'Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 241 ;
	}

#paramId: 500467
#UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds
'UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 242 ;
	}

#paramId: 500468
#UV Index, clear sky, maximum
'UV Index, clear sky, maximum' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 243 ;
	}

#paramId: 500469
#Total ozone
'Total ozone' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 247 ;
	}

#paramId: 500471
#Time of maximum of UV Index, clouded
'Time of maximum of UV Index, clouded' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 249 ;
	}

#paramId: 500472
#Konvektionsart (0..4)
'Konvektionsart (0..4)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500473
#perceived temperature
'perceived temperature' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 500475
#Water temperature
'Water temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 500476
#Water temperature in C
'Water temperature in C' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500477
#Absolute Vorticity
'Absolute Vorticity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500478
#probability to perceive sultriness
'probability to perceive sultriness' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 500479
#value of isolation of clothes
'value of isolation of clothes' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 58 ;
	}

#paramId: 500480
#Downward direct short wave radiation flux at surface (mean over forecast time)
'Downward direct short wave radiation flux at surface (mean over forecast time)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 22 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500481
#Downward diffusive short wave radiation flux
'Downward diffusive short wave radiation flux' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 23 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500482
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'Upward diffusive short wave radiation flux at surface ( mean over forecast time)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 24 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 500486
#vertical integral of divergence of total water content (s)
'vertical integral of divergence of total water content (s)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 42 ;
	 timeRangeIndicator = 0 ;
	}

#paramId: 500487
#Downward direct short wave radiation flux at surface (mean over forecast time) Initialisation
'Downward direct short wave radiation flux at surface (mean over forecast time) Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 22 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500488
#Downward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation
'Downward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 23 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500489
#Upward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation
'Upward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 24 ;
	 indicatorOfTypeOfLevel = 1 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 500490
#Water Fraction
'Water Fraction' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 500491
#Lake depth
'Lake depth' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 500492
#Wind fetch
'Wind fetch' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 500493
#Attenuation coefficient of water with respect to solar radiation
'Attenuation coefficient of water with respect to solar radiation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500494
#Depth of thermally active layer of bottom sediment
'Depth of thermally active layer of bottom sediment' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500495
#Temperature at the lower boundary of the thermally active layer of bottom sediment
'Temperature at the lower boundary of the thermally active layer of bottom sediment' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 190 ;
	}

#paramId: 500496
#Mean temperature of the water column
'Mean temperature of the water column' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500497
#Mixed-layer temperature
'Mixed-layer temperature' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 193 ;
	}

#paramId: 500498
#Bottom temperature (temperature at the water-bottom sediment interface)
'Bottom temperature (temperature at the water-bottom sediment interface)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500499
#Mixed-layer depth
'Mixed-layer depth' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 500500
#Shape factor with respect to the temperature profile in the thermocline
'Shape factor with respect to the temperature profile in the thermocline' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500501
#Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)
'Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 192 ;
	}

#paramId: 500502
#Sediment thickness of the upper layer of bottom sediments
'Sediment thickness of the upper layer of bottom sediments' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 500503
#Icing Base (hft) - Prognose Icing Degree Composit
'Icing Base (hft) - Prognose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500504
#Icing Max Base (hft) - Prognose Icing Degree Composit
'Icing Max Base (hft) - Prognose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500505
#Icing Max Top (hft) - Prognose Icing Degree Composit
'Icing Max Top (hft) - Prognose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500506
#Icing Top (hft) - Prognose Icing Degree Composit
'Icing Top (hft) - Prognose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500507
#Icing Vertical Code (1=continuous,2=discontinuous) - Prognose Icing Degree Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Prognose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500508
#Icing Max Code (1=light,2=moderate,3=severe) - Prognose Icing Degree Composit
'Icing Max Code (1=light,2=moderate,3=severe) - Prognose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 181 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500509
#Icing Base (hft) - Prognose Icing Scenario Composit
'Icing Base (hft) - Prognose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500510
#Icing Signifikant Base (hft) - Prognose Icing Scenario Composit
'Icing Signifikant Base (hft) - Prognose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500511
#Icing Signifikant Top (hft) - Prognose Icing Scenario Composit
'Icing Signifikant Top (hft) - Prognose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500512
#Icing Top (hft) - Prognose Icing Scenario Composit
'Icing Top (hft) - Prognose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500513
#Icing Vertical Code (1=continuous,2=discontinuous) - Prognose Icing Scenario Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Prognose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500514
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Prognose Icing Scenario Composit
'Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Prognose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 182 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500515
#Icing Base (hft) - Diagnose Icing Degree Composit
'Icing Base (hft) - Diagnose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500516
#Icing Max Base (hft) - Diagnose Icing Degree Composit
'Icing Max Base (hft) - Diagnose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500517
#Icing Max Top (hft) - Diagnose Icing Degree Composit
'Icing Max Top (hft) - Diagnose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500518
#Icing Top (hft) - Diagnose Icing Degree Composit
'Icing Top (hft) - Diagnose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500519
#Icing Vertical Code (1=continuous,2=discontinuous) - Diagnose Icing Degree Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Diagnose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500520
#Icing Max Code (1=light,2=moderate,3=severe) - Diagnose Icing Degree Composit
'Icing Max Code (1=light,2=moderate,3=severe) - Diagnose Icing Degree Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 183 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500521
#Icing Base (hft) - Diagnose Icing Scenario Composit
'Icing Base (hft) - Diagnose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 1 ;
	}

#paramId: 500522
#Icing Signifikant Base (hft) - Diagnose Icing Scenario Composit
'Icing Signifikant Base (hft) - Diagnose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 2 ;
	}

#paramId: 500523
#Icing Signifikant Top (hft) - Diagnose Icing Scenario Composit
'Icing Signifikant Top (hft) - Diagnose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 3 ;
	}

#paramId: 500524
#Icing Top (hft) - Diagnose Icing Scenario Composit
'Icing Top (hft) - Diagnose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 4 ;
	}

#paramId: 500525
#Icing Vertical Code (1=continuous,2=discontinuous) - Diagnose Icing Scenario Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Diagnose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 5 ;
	}

#paramId: 500526
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Diagnose Icing Scenario Composit
'Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Diagnose Icing Scenario Composit' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 184 ;
	 indicatorOfTypeOfLevel = 202 ;
	 level = 6 ;
	}

#paramId: 500527
#Prognose Icing Degree Code (1=light,2=moderate,3=severe)
'Prognose Icing Degree Code (1=light,2=moderate,3=severe)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500528
#Prognose Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'Prognose Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 192 ;
	}

#paramId: 500529
#Diagnose Icing Degree Code (1=light,2=moderate,3=severe)
'Diagnose Icing Degree Code (1=light,2=moderate,3=severe)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 193 ;
	}

#paramId: 500530
#Diagnose Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'Diagnose Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500531
#current weather (symbol number: 0..9)
'current weather (symbol number: 0..9)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 205 ;
	}

#paramId: 500541
#relative vorticity,U-component
'relative vorticity,U-component' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 133 ;
	}

#paramId: 500542
#relative vorticity,V-component
'relative vorticity,V-component' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 134 ;
	}

#paramId: 500543
#vertical vorticity
'vertical vorticity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500544
#Potential vorticity
'Potential vorticity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500545
#Density
'Density' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 500547
#Convective Precipitation (difference)
'Convective Precipitation (difference)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	 timeRangeIndicator = 5 ;
	}

#paramId: 500550
#Potentielle Vorticity (auf Druckflaechen, nicht isentrop)
'Potentielle Vorticity (auf Druckflaechen, nicht isentrop)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 500551
#geostrophische Vorticity
'geostrophische Vorticity' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500552
#Forcing rechte Seite Omegagleichung
'Forcing rechte Seite Omegagleichung' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500553
#Q-Vektor X-Komponente (geostrophisch)
'Q-Vektor X-Komponente (geostrophisch)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 500554
#Q-Vektor Y-Komponente (geostrophisch)
'Q-Vektor Y-Komponente (geostrophisch)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 500555
#Divergenz Q (geostrophisch)
'Divergenz Q (geostrophisch)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500556
#Q-Vektor senkrecht zu d. Isothermen (geostrophisch)
'Q-Vektor senkrecht zu d. Isothermen (geostrophisch)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 500557
#Q-Vektor parallel zu d. Isothermen (geostrophisch)
'Q-Vektor parallel zu d. Isothermen (geostrophisch)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 500558
#Divergenz Qn geostrophisch
'Divergenz Qn geostrophisch' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 500559
#Divergenz Qs geostrophisch
'Divergenz Qs geostrophisch' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500560
#Frontogenesefunktion
'Frontogenesefunktion' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 500562
#Divergenz
'Divergenz' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500563
#Q-Vektor parallel zu den Isothermen
'Q-Vektor parallel zu den Isothermen' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 500564
#Divergenz Qn
'Divergenz Qn' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 500565
#Divergenz Qs
'Divergenz Qs' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 500566
#Frontogenesis function
'Frontogenesis function' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 128 ;
	}

#paramId: 500567
#Clear Air Turbulence Index
'Clear Air Turbulence Index' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 146 ;
	}

#paramId: 500568
#Geopotential height
'Geopotential height' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500569
#Relative Divergenz
'Relative Divergenz' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500570
#dry convection top index
'dry convection top index' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 500571
#- FE1 I128A[AMP]ROUTI von 199809 bis 199905
'- FE1 I128A[AMP]ROUTI von 199809 bis 199905' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 231 ;
	}

#paramId: 500572
#tidal tendencies
'tidal tendencies' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500573
#Sea surface temperature interpolated in time in C
'Sea surface temperature interpolated in time in C' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500574
#Logarithm of Pressure
'Logarithm of Pressure' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 500575
#3 hour pressure change
'3 hour pressure change' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500576
#covariance of soil moisture content (0-10)
'covariance of soil moisture content (0-10)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 74 ;
	 localElementNumber = 2 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	}

#paramId: 500579
#Soil Temperature (layer)
'Soil Temperature (layer)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	 indicatorOfTypeOfLevel = 112 ;
	}

#paramId: 500580
#Soil Moisture Content (0-7 cm)
'Soil Moisture Content (0-7 cm)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 0 ;
	 bottomLevel = 7 ;
	}

#paramId: 500581
#Soil Moisture Content (7-50 cm)
'Soil Moisture Content (7-50 cm)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	 indicatorOfTypeOfLevel = 112 ;
	 topLevel = 7 ;
	 bottomLevel = 50 ;
	}

#paramId: 500582
#Max 2m Temperature (i) Initialisation
'Max 2m Temperature (i) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 1 ;
	 level = 2 ;
	}

#paramId: 500583
#Min 2m Temperature (i) Initialisation
'Min 2m Temperature (i) Initialisation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 timeRangeIndicator = 1 ;
	 level = 2 ;
	}

#paramId: 500585
#Eddy Dissipation Rate
'Eddy Dissipation Rate' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500586
#Ellrod Index
'Ellrod Index' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500588
#Snow melt
'Snow melt' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500590
#ICAO Standard Atmosphere reference height
'ICAO Standard Atmosphere reference height' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500592
#Geopotential height
'Geopotential height' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500593
#Global radiation flux
'Global radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500600
#Prob Windboeen > 25 kn
'Prob Windboeen > 25 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500601
#Prob Windboeen > 27 kn
'Prob Windboeen > 27 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500602
#Prob Sturmboeen > 33 kn
'Prob Sturmboeen > 33 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500603
#Prob Sturmboeen > 40 kn
'Prob Sturmboeen > 40 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500604
#Prob Schwere Sturmboeen > 47 kn
'Prob Schwere Sturmboeen > 47 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500605
#Prob Orkanartige Boeen > 55 kn
'Prob Orkanartige Boeen > 55 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500606
#Prob Orkanboeen > 63 kn
'Prob Orkanboeen > 63 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500607
#Prob Oberoertliche Orkanboeen > 75 kn
'Prob Oberoertliche Orkanboeen > 75 kn' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500608
#Prob Starkregen > 10 mm
'Prob Starkregen > 10 mm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500609
#Prob Heftiger Starkregen > 25 mm
'Prob Heftiger Starkregen > 25 mm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500610
#Prob Extrem Heftiger Starkregen > 50 mm
'Prob Extrem Heftiger Starkregen > 50 mm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500611
#Prob Leichter Schneefall > 0,1 mm
'Prob Leichter Schneefall > 0,1 mm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 500612
#Prob Leichter Schneefall > 0,1 cm
'Prob Leichter Schneefall > 0,1 cm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500613
#Prob Leichter Schneefall > 0,5 cm
'Prob Leichter Schneefall > 0,5 cm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500614
#Prob Leichter Schneefall > 1 cm
'Prob Leichter Schneefall > 1 cm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 500615
#Prob Schneefall > 5 cm
'Prob Schneefall > 5 cm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 500616
#Prob Starker Schneefall > 10 cm
'Prob Starker Schneefall > 10 cm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500617
#Prob Extrem starker Schneefall > 25 cm
'Prob Extrem starker Schneefall > 25 cm' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 500618
#Prob Frost
'Prob Frost' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500619
#Prob Strenger Frost
'Prob Strenger Frost' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 500620
#Prob Gewitter
'Prob Gewitter' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 500621
#Prob Starkes Gewitter
'Prob Starkes Gewitter' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 500622
#Prob Schweres Gewitter
'Prob Schweres Gewitter' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 500623
#Prob Dauerregen
'Prob Dauerregen' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 500624
#Prob Ergiebiger Dauerregen
'Prob Ergiebiger Dauerregen' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 500625
#Prob Extrem ergiebiger Dauerregen
'Prob Extrem ergiebiger Dauerregen' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 500626
#Prob Schneeverwehung
'Prob Schneeverwehung' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 500627
#Prob Starke Schneeverwehung
'Prob Starke Schneeverwehung' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 500628
#Prob Glaette
'Prob Glaette' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500629
#Prob oertlich Glatteis
'Prob oertlich Glatteis' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500630
#Prob Glatteis
'Prob Glatteis' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500631
#Prob Nebel (ueberoertl. Sichtweite < 150 m)
'Prob Nebel (ueberoertl. Sichtweite < 150 m)' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500632
#Prob Tauwetter
'Prob Tauwetter' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500633
#Prob Starkes Tauwetter
'Prob Starkes Tauwetter' = {
	 table2Version = 210 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500634
#wake-production of TKE due to sub grid scale orography
'wake-production of TKE due to sub grid scale orography' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 155 ;
	}

#paramId: 500635
#shear-production of TKE due to separated horizontal shear modes
'shear-production of TKE due to separated horizontal shear modes' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 156 ;
	}

#paramId: 500636
#buoyancy-production of TKE due to sub grid scale convection
'buoyancy-production of TKE due to sub grid scale convection' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 157 ;
	}

#paramId: 500638
#Atmospheric Resistance
'Atmospheric Resistance' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 211 ;
	}

#paramId: 500639
#Height of thermals above MSL
'Height of thermals above MSL' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 500640
#mass concentration of dust (minimum mode)
'mass concentration of dust (minimum mode)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500642
#Lapse rate
'Lapse rate' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500643
#mass concentration of dust (medium mode)
'mass concentration of dust (medium mode)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500644
#mass concentration of dust (maximum mode)
'mass concentration of dust (maximum mode)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 500645
#number concentration of dust (minimum mode)
'number concentration of dust (minimum mode)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500646
#number concentration of dust (medium mode)
'number concentration of dust (medium mode)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 500647
#number concentration of dust (maximum mode)
'number concentration of dust (maximum mode)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500648
#mass concentration of dust (sum of all modes)
'mass concentration of dust (sum of all modes)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 251 ;
	}

#paramId: 500649
#number concentration of dust (sum of all modes)
'number concentration of dust (sum of all modes)' = {
	 table2Version = 242 ;
	 indicatorOfParameter = 252 ;
	}

#paramId: 500650
#DUMMY_1
'DUMMY_1' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 500651
#DUMMY_2
'DUMMY_2' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 500652
#DUMMY_3
'DUMMY_3' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 500654
#DUMMY_4
'DUMMY_4' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 500655
#DUMMY_5
'DUMMY_5' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 500656
#DUMMY_6
'DUMMY_6' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 500657
#DUMMY_7
'DUMMY_7' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 500658
#DUMMY_8
'DUMMY_8' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 500659
#DUMMY_9
'DUMMY_9' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 500660
#DUMMY_10
'DUMMY_10' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 500661
#DUMMY_11
'DUMMY_11' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 500662
#DUMMY_12
'DUMMY_12' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 500663
#DUMMY_13
'DUMMY_13' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 500664
#DUMMY_14
'DUMMY_14' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 500665
#DUMMY_15
'DUMMY_15' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 500666
#DUMMY_16
'DUMMY_16' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 500667
#DUMMY_17
'DUMMY_17' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 500668
#DUMMY_18
'DUMMY_18' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 500669
#DUMMY_19
'DUMMY_19' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 500670
#DUMMY_20
'DUMMY_20' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 500671
#DUMMY_21
'DUMMY_21' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 500672
#DUMMY_22
'DUMMY_22' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 500673
#DUMMY_23
'DUMMY_23' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 500674
#DUMMY_24
'DUMMY_24' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 500675
#DUMMY_25
'DUMMY_25' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 500676
#DUMMY_26
'DUMMY_26' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 500677
#DUMMY_27
'DUMMY_27' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 500678
#DUMMY_28
'DUMMY_28' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 500679
#DUMMY_29
'DUMMY_29' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 500680
#DUMMY_30
'DUMMY_30' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 500681
#DUMMY_31
'DUMMY_31' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 500682
#DUMMY_32
'DUMMY_32' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 500683
#DUMMY_33
'DUMMY_33' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 500684
#DUMMY_34
'DUMMY_34' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 500685
#DUMMY_35
'DUMMY_35' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 500686
#DUMMY_36
'DUMMY_36' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 500687
#DUMMY_37
'DUMMY_37' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 500688
#DUMMY_38
'DUMMY_38' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 500689
#DUMMY_39
'DUMMY_39' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 500690
#DUMMY_40
'DUMMY_40' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 500691
#DUMMY_41
'DUMMY_41' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 500692
#DUMMY_42
'DUMMY_42' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 500693
#DUMMY_43
'DUMMY_43' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 500694
#DUMMY_44
'DUMMY_44' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 500695
#DUMMY_45
'DUMMY_45' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 500696
#DUMMY_46
'DUMMY_46' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 500697
#DUMMY_47
'DUMMY_47' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 500698
#DUMMY_48
'DUMMY_48' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 500699
#DUMMY_49
'DUMMY_49' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 500700
#DUMMY_50
'DUMMY_50' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 500701
#DUMMY_51
'DUMMY_51' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 500702
#DUMMY_52
'DUMMY_52' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 500703
#DUMMY_53
'DUMMY_53' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 500704
#DUMMY_54
'DUMMY_54' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 500705
#DUMMY_55
'DUMMY_55' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 500706
#DUMMY_56
'DUMMY_56' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 500707
#DUMMY_57
'DUMMY_57' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 500708
#DUMMY_58
'DUMMY_58' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 58 ;
	}

#paramId: 500709
#DUMMY_59
'DUMMY_59' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 500710
#DUMMY_60
'DUMMY_60' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 500711
#DUMMY_61
'DUMMY_61' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 500712
#DUMMY_62
'DUMMY_62' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 500713
#DUMMY_63
'DUMMY_63' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 500714
#DUMMY_64
'DUMMY_64' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 500715
#DUMMY_65
'DUMMY_65' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 500716
#DUMMY_66
'DUMMY_66' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 500717
#DUMMY_67
'DUMMY_67' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 500718
#DUMMY_68
'DUMMY_68' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 500719
#DUMMY_69
'DUMMY_69' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 500720
#DUMMY_70
'DUMMY_70' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 500721
#DUMMY_71
'DUMMY_71' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 500722
#DUMMY_72
'DUMMY_72' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 500723
#DUMMY_73
'DUMMY_73' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 500724
#DUMMY_74
'DUMMY_74' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 500725
#DUMMY_75
'DUMMY_75' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 500726
#DUMMY_76
'DUMMY_76' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 500727
#DUMMY_77
'DUMMY_77' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 500728
#DUMMY_78
'DUMMY_78' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 500729
#DUMMY_79
'DUMMY_79' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 500730
#DUMMY_80
'DUMMY_80' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 500731
#DUMMY_81
'DUMMY_81' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 500732
#DUMMY_82
'DUMMY_82' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 500733
#DUMMY_83
'DUMMY_83' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 500734
#DUMMY_84
'DUMMY_84' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 500735
#DUMMY_85
'DUMMY_85' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 500736
#DUMMY_86
'DUMMY_86' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 500737
#DUMMY_87
'DUMMY_87' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 500738
#DUMMY_88
'DUMMY_88' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 500739
#DUMMY_89
'DUMMY_89' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 500740
#DUMMY_90
'DUMMY_90' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 500741
#DUMMY_91
'DUMMY_91' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 500742
#DUMMY_92
'DUMMY_92' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 500743
#DUMMY_93
'DUMMY_93' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 500744
#DUMMY_94
'DUMMY_94' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 500745
#DUMMY_95
'DUMMY_95' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 500746
#DUMMY_96
'DUMMY_96' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 500747
#DUMMY_97
'DUMMY_97' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 500748
#DUMMY_98
'DUMMY_98' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 500749
#DUMMY_99
'DUMMY_99' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 500750
#DUMMY_100
'DUMMY_100' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 500751
#DUMMY_101
'DUMMY_101' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 500752
#DUMMY_102
'DUMMY_102' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 500753
#DUMMY_103
'DUMMY_103' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 500754
#DUMMY_104
'DUMMY_104' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 500755
#DUMMY_105
'DUMMY_105' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 500756
#DUMMY_106
'DUMMY_106' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 500757
#DUMMY_107
'DUMMY_107' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 107 ;
	}

#paramId: 500758
#DUMMY_108
'DUMMY_108' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 108 ;
	}

#paramId: 500759
#DUMMY_109
'DUMMY_109' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 500760
#DUMMY_110
'DUMMY_110' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 500761
#DUMMY_111
'DUMMY_111' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 500762
#DUMMY_112
'DUMMY_112' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 500763
#DUMMY_113
'DUMMY_113' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 500764
#DUMMY_114
'DUMMY_114' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 500765
#DUMMY_115
'DUMMY_115' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 500766
#DUMMY_116
'DUMMY_116' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 500767
#DUMMY_117
'DUMMY_117' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 500768
#DUMMY_118
'DUMMY_118' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 500769
#DUMMY_119
'DUMMY_119' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 500770
#DUMMY_120
'DUMMY_120' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 500771
#DUMMY_121
'DUMMY_121' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 500772
#DUMMY_122
'DUMMY_122' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 500773
#DUMMY_123
'DUMMY_123' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 500774
#DUMMY_124
'DUMMY_124' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 500775
#DUMMY_125
'DUMMY_125' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 500776
#DUMMY_126
'DUMMY_126' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 500777
#DUMMY_127
'DUMMY_127' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 500778
#DUMMY_128
'DUMMY_128' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 128 ;
	}

#paramId: 500779
#DUMMY_129
'DUMMY_129' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 129 ;
	}

#paramId: 500780
#DUMMY_130
'DUMMY_130' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 130 ;
	}

#paramId: 500781
#DUMMY_131
'DUMMY_131' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 131 ;
	}

#paramId: 500782
#DUMMY_132
'DUMMY_132' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 132 ;
	}

#paramId: 500783
#DUMMY_133
'DUMMY_133' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 133 ;
	}

#paramId: 500784
#DUMMY_134
'DUMMY_134' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 134 ;
	}

#paramId: 500785
#DUMMY_135
'DUMMY_135' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 135 ;
	}

#paramId: 500786
#DUMMY_136
'DUMMY_136' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 136 ;
	}

#paramId: 500787
#DUMMY_137
'DUMMY_137' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 137 ;
	}

#paramId: 500788
#DUMMY_138
'DUMMY_138' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 138 ;
	}

#paramId: 500789
#DUMMY_139
'DUMMY_139' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 139 ;
	}

#paramId: 500790
#DUMMY_140
'DUMMY_140' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 140 ;
	}

#paramId: 500791
#DUMMY_141
'DUMMY_141' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 141 ;
	}

#paramId: 500792
#DUMMY_142
'DUMMY_142' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 142 ;
	}

#paramId: 500793
#DUMMY_143
'DUMMY_143' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 143 ;
	}

#paramId: 500794
#DUMMY_144
'DUMMY_144' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 144 ;
	}

#paramId: 500795
#DUMMY_145
'DUMMY_145' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 145 ;
	}

#paramId: 500796
#DUMMY_146
'DUMMY_146' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 146 ;
	}

#paramId: 500797
#DUMMY_147
'DUMMY_147' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 147 ;
	}

#paramId: 500798
#DUMMY_148
'DUMMY_148' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 148 ;
	}

#paramId: 500799
#DUMMY_149
'DUMMY_149' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 149 ;
	}

#paramId: 500800
#DUMMY_150
'DUMMY_150' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 150 ;
	}

#paramId: 500801
#DUMMY_151
'DUMMY_151' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 151 ;
	}

#paramId: 500802
#DUMMY_152
'DUMMY_152' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 152 ;
	}

#paramId: 500803
#DUMMY_153
'DUMMY_153' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 153 ;
	}

#paramId: 500804
#DUMMY_154
'DUMMY_154' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 154 ;
	}

#paramId: 500805
#DUMMY_155
'DUMMY_155' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 155 ;
	}

#paramId: 500806
#DUMMY_156
'DUMMY_156' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 156 ;
	}

#paramId: 500807
#DUMMY_157
'DUMMY_157' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 157 ;
	}

#paramId: 500808
#DUMMY_158
'DUMMY_158' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 158 ;
	}

#paramId: 500809
#DUMMY_159
'DUMMY_159' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 159 ;
	}

#paramId: 500810
#DUMMY_160
'DUMMY_160' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 160 ;
	}

#paramId: 500811
#DUMMY_161
'DUMMY_161' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 161 ;
	}

#paramId: 500812
#DUMMY_162
'DUMMY_162' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 162 ;
	}

#paramId: 500813
#DUMMY_163
'DUMMY_163' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 163 ;
	}

#paramId: 500814
#DUMMY_164
'DUMMY_164' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 164 ;
	}

#paramId: 500815
#DUMMY_165
'DUMMY_165' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 165 ;
	}

#paramId: 500816
#DUMMY_166
'DUMMY_166' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 166 ;
	}

#paramId: 500817
#DUMMY_167
'DUMMY_167' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 167 ;
	}

#paramId: 500818
#DUMMY_168
'DUMMY_168' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 168 ;
	}

#paramId: 500819
#DUMMY_169
'DUMMY_169' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 169 ;
	}

#paramId: 500820
#DUMMY_170
'DUMMY_170' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 170 ;
	}

#paramId: 500821
#DUMMY_171
'DUMMY_171' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 171 ;
	}

#paramId: 500822
#DUMMY_172
'DUMMY_172' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 172 ;
	}

#paramId: 500823
#DUMMY_173
'DUMMY_173' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 173 ;
	}

#paramId: 500824
#DUMMY_174
'DUMMY_174' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 174 ;
	}

#paramId: 500825
#DUMMY_175
'DUMMY_175' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 175 ;
	}

#paramId: 500826
#DUMMY_176
'DUMMY_176' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 176 ;
	}

#paramId: 500827
#DUMMY_177
'DUMMY_177' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 177 ;
	}

#paramId: 500828
#DUMMY_178
'DUMMY_178' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 178 ;
	}

#paramId: 500829
#DUMMY_179
'DUMMY_179' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 179 ;
	}

#paramId: 500830
#DUMMY_180
'DUMMY_180' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 180 ;
	}

#paramId: 500831
#DUMMY_181
'DUMMY_181' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 181 ;
	}

#paramId: 500832
#DUMMY_182
'DUMMY_182' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 182 ;
	}

#paramId: 500833
#DUMMY_183
'DUMMY_183' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 183 ;
	}

#paramId: 500834
#DUMMY_184
'DUMMY_184' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 184 ;
	}

#paramId: 500835
#DUMMY_185
'DUMMY_185' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 185 ;
	}

#paramId: 500836
#DUMMY_186
'DUMMY_186' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 186 ;
	}

#paramId: 500837
#DUMMY_187
'DUMMY_187' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 187 ;
	}

#paramId: 500838
#DUMMY_188
'DUMMY_188' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 188 ;
	}

#paramId: 500839
#DUMMY_189
'DUMMY_189' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 189 ;
	}

#paramId: 500840
#DUMMY_190
'DUMMY_190' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 190 ;
	}

#paramId: 500841
#DUMMY_191
'DUMMY_191' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 191 ;
	}

#paramId: 500842
#DUMMY_192
'DUMMY_192' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 192 ;
	}

#paramId: 500843
#DUMMY_193
'DUMMY_193' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 193 ;
	}

#paramId: 500844
#DUMMY_194
'DUMMY_194' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 194 ;
	}

#paramId: 500845
#DUMMY_195
'DUMMY_195' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 195 ;
	}

#paramId: 500846
#DUMMY_196
'DUMMY_196' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 500847
#DUMMY_197
'DUMMY_197' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 197 ;
	}

#paramId: 500848
#DUMMY_198
'DUMMY_198' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 198 ;
	}

#paramId: 500849
#DUMMY_199
'DUMMY_199' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 199 ;
	}

#paramId: 500850
#DUMMY_200
'DUMMY_200' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 200 ;
	}

#paramId: 500851
#DUMMY_201
'DUMMY_201' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 201 ;
	}

#paramId: 500852
#DUMMY_202
'DUMMY_202' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 202 ;
	}

#paramId: 500853
#DUMMY_203
'DUMMY_203' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 203 ;
	}

#paramId: 500854
#DUMMY_204
'DUMMY_204' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 204 ;
	}

#paramId: 500855
#DUMMY_205
'DUMMY_205' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 205 ;
	}

#paramId: 500856
#DUMMY_206
'DUMMY_206' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 206 ;
	}

#paramId: 500857
#DUMMY_207
'DUMMY_207' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 207 ;
	}

#paramId: 500858
#DUMMY_208
'DUMMY_208' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 208 ;
	}

#paramId: 500859
#DUMMY_209
'DUMMY_209' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 209 ;
	}

#paramId: 500860
#DUMMY_210
'DUMMY_210' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 210 ;
	}

#paramId: 500861
#DUMMY_211
'DUMMY_211' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 211 ;
	}

#paramId: 500862
#DUMMY_212
'DUMMY_212' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 212 ;
	}

#paramId: 500863
#DUMMY_213
'DUMMY_213' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 213 ;
	}

#paramId: 500864
#DUMMY_214
'DUMMY_214' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 214 ;
	}

#paramId: 500865
#DUMMY_215
'DUMMY_215' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 215 ;
	}

#paramId: 500866
#DUMMY_216
'DUMMY_216' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 216 ;
	}

#paramId: 500867
#DUMMY_217
'DUMMY_217' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 217 ;
	}

#paramId: 500868
#DUMMY_218
'DUMMY_218' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 218 ;
	}

#paramId: 500869
#DUMMY_219
'DUMMY_219' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 219 ;
	}

#paramId: 500870
#DUMMY_220
'DUMMY_220' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 220 ;
	}

#paramId: 500871
#DUMMY_221
'DUMMY_221' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 221 ;
	}

#paramId: 500872
#DUMMY_222
'DUMMY_222' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 222 ;
	}

#paramId: 500873
#DUMMY_223
'DUMMY_223' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 223 ;
	}

#paramId: 500874
#DUMMY_224
'DUMMY_224' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 224 ;
	}

#paramId: 500875
#DUMMY_225
'DUMMY_225' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 225 ;
	}

#paramId: 500876
#DUMMY_226
'DUMMY_226' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 226 ;
	}

#paramId: 500877
#DUMMY_227
'DUMMY_227' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 227 ;
	}

#paramId: 500878
#DUMMY_228
'DUMMY_228' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 228 ;
	}

#paramId: 500879
#DUMMY_229
'DUMMY_229' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 229 ;
	}

#paramId: 500880
#DUMMY_230
'DUMMY_230' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 230 ;
	}

#paramId: 500881
#DUMMY_231
'DUMMY_231' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 231 ;
	}

#paramId: 500882
#DUMMY_232
'DUMMY_232' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 232 ;
	}

#paramId: 500883
#DUMMY_233
'DUMMY_233' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 233 ;
	}

#paramId: 500884
#DUMMY_234
'DUMMY_234' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 234 ;
	}

#paramId: 500885
#DUMMY_235
'DUMMY_235' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 235 ;
	}

#paramId: 500886
#DUMMY_236
'DUMMY_236' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 236 ;
	}

#paramId: 500887
#DUMMY_237
'DUMMY_237' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 237 ;
	}

#paramId: 500888
#DUMMY_238
'DUMMY_238' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 238 ;
	}

#paramId: 500889
#DUMMY_239
'DUMMY_239' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 239 ;
	}

#paramId: 500890
#DUMMY_240
'DUMMY_240' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 240 ;
	}

#paramId: 500891
#DUMMY_241
'DUMMY_241' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 241 ;
	}

#paramId: 500892
#DUMMY_242
'DUMMY_242' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 242 ;
	}

#paramId: 500893
#DUMMY_243
'DUMMY_243' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 243 ;
	}

#paramId: 500894
#DUMMY_244
'DUMMY_244' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 244 ;
	}

#paramId: 500895
#DUMMY_245
'DUMMY_245' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 245 ;
	}

#paramId: 500896
#DUMMY_246
'DUMMY_246' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 246 ;
	}

#paramId: 500897
#DUMMY_247
'DUMMY_247' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 247 ;
	}

#paramId: 500898
#DUMMY_248
'DUMMY_248' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 248 ;
	}

#paramId: 500899
#DUMMY_249
'DUMMY_249' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 249 ;
	}

#paramId: 500900
#DUMMY_250
'DUMMY_250' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 250 ;
	}

#paramId: 500901
#DUMMY_251
'DUMMY_251' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 251 ;
	}

#paramId: 500902
#DUMMY_252
'DUMMY_252' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 252 ;
	}

#paramId: 500903
#DUMMY_253
'DUMMY_253' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 253 ;
	}

#paramId: 500904
#DUMMY_254
'DUMMY_254' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 254 ;
	}

#paramId: 500905
#Specific Humidity (S)
'Specific Humidity (S)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502307
#Albedo - diffusive solar - time average (0.3 - 5.0 m-6)
'Albedo - diffusive solar - time average (0.3 - 5.0 m-6) ' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 129 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 502308
#Albedo - diffusive solar (0.3 - 5.0 m-6)
'Albedo - diffusive solar (0.3 - 5.0 m-6)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 129 ;
	}

#paramId: 502317
#Latent Heat Net Flux - instant - at surface
'Latent Heat Net Flux - instant - at surface' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502318
#Sensible Heat Net Flux - instant - at surface
'Sensible Heat Net Flux - instant - at surface' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502333
#salinity
'salinity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 502334
#Stream function
'Stream function' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 502335
#Velocity potential
'Velocity potential' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 502336
#Skin temperature
'Skin temperature' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502339
#Downward direct short wave radiation flux
'Downward direct short wave radiation flux' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 22 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502350
#Temperature (G)
'Temperature (G)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502355
#Stream function
'Stream function' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 502356
#Velocity potential
'Velocity potential' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 502357
#Wind speed (SP)
'Wind speed (SP)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 502358
#Pressure
'Pressure' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 502359
#Potential vorticity
'Potential vorticity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 502360
#Potential vorticity
'Potential vorticity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 4 ;
	}

#paramId: 502361
#Geopotential
'Geopotential' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 502362
#Max 2m Temperature
'Max 2m Temperature ' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502363
#Min 2m Temperature
'Min 2m Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502364
#Temperature
'Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 502365
#U-Component of Wind
'U-Component of Wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 502366
#Pressure (S) (not reduced)
'Pressure (S) (not reduced)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502367
#V-Component of Wind
'V-Component of Wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 502368
#Specific Humidity
'Specific Humidity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 502369
#Vertical Velocity (Pressure) ( omega=dp/dt )
'Vertical Velocity (Pressure) ( omega=dp/dt )' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 502370
#vertical vorticity
'vertical vorticity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 502371
#Sensible Heat Net Flux (m)
'Sensible Heat Net Flux (m)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 502372
#Latent Heat Net Flux (m)
'Latent Heat Net Flux (m)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 502373
#Pressure Reduced to MSL
'Pressure Reduced to MSL' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 502374
#Relative Divergenz
'Relative Divergenz' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 502375
#Geopotential height
'Geopotential height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 502376
#Relative Humidity
'Relative Humidity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 502377
#U-Component of Wind
'U-Component of Wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502378
#V-Component of Wind
'V-Component of Wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502379
#2m Temperature
'2m Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502381
#Land Cover (1=land, 0=sea)
'Land Cover (1=land, 0=sea)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 502382
#Surface Roughness length Surface Roughness
'Surface Roughness length Surface Roughness' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 502383
#Albedo (in short-wave, average)
'Albedo (in short-wave, average)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 502384
#Evaporation (s)
'Evaporation (s)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 502385
#Convective Cloud Cover
'Convective Cloud Cover' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 502386
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 502387
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 502388
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 502389
#Plant cover
'Plant cover' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 502390
#Water Runoff
'Water Runoff ' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 502391
#Total Column Integrated Ozone
'Total Column Integrated Ozone' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 502392
#Convective Snowfall water equivalent (s)
'Convective Snowfall water equivalent (s)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 502393
#Large-Scale snowfall - water equivalent (Accumulation)
'Large-Scale snowfall - water equivalent (Accumulation)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 502394
#Large-Scale Precipitation
'Large-Scale Precipitation ' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 502395
#Total Column-Integrated Cloud Water
'Total Column-Integrated Cloud Water' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 502396
#Virtual Temperature
'Virtual Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 502397
#Virtual Temperature
'Virtual Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 502398
#Virtual Temperature
'Virtual Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 12 ;
	}

#paramId: 502399
#Brightness Temperature
'Brightness Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 502400
#Boundary Layer Dissipitation
'Boundary Layer Dissipitation' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 502401
#Pressure Tendency
'Pressure Tendency ' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 502402
#ICAO Standard Atmosphere reference height
'ICAO Standard Atmosphere reference height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 502403
#Geometric Height
'Geometric Height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 502404
#Max Temperature
'Max Temperature ' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 502405
#Min Temperature
'Min Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 502406
#Dew Point Temperature
'Dew Point Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 502407
#Dew point depression(or deficit)
'Dew point depression(or deficit)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 502408
#Lapse rate
'Lapse rate' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 502409
#Visibility
'Visibility' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 502410
#Radar spectra (1)
'Radar spectra (1)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 502411
#Radar spectra (2)
'Radar spectra (2)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 502412
#Radar spectra (3)
'Radar spectra (3)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 502413
#Parcel lifted index (to 500 hPa)
'Parcel lifted index (to 500 hPa)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 502414
#Temperature anomaly
'Temperature anomaly' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 502415
#Pressure anomaly
'Pressure anomaly' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 502416
#Geopotential height anomaly
'Geopotential height anomaly' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 502417
#Wave spectra (1)
'Wave spectra (1)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 502418
#Wave spectra (2)
'Wave spectra (2)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 502419
#Wave spectra (3)
'Wave spectra (3)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 502420
#Wind Direction (DD)
'Wind Direction (DD)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 502421
#Sigma coordinate vertical velocity
'Sigma coordinate vertical velocity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502422
#Absolute Vorticity
'Absolute Vorticity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 502423
#Absolute divergence
'Absolute divergence' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 502424
#Vertical u-component shear
'Vertical u-component shear' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 502425
#Vertical v-component shear
'Vertical v-component shear' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 502426
#Direction of current
'Direction of current' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 502427
#Speed of current
'Speed of current' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 502428
#U-component of current
'U-component of current' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 502429
#V-component of current
'V-component of current' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 502430
#Humidity mixing ratio
'Humidity mixing ratio' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 502431
#Precipitable water
'Precipitable water' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 502432
#Vapour pressure
'Vapour pressure' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 502433
#Saturation deficit
'Saturation deficit' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 502434
#Precipitation rate
'Precipitation rate' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 502435
#Thunderstorm probability
'Thunderstorm probability' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 502436
#Convective precipitation (water)
'Convective precipitation (water)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 502437
#Snow fall rate water equivalent
'Snow fall rate water equivalent' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 502438
#Mixed layer depth
'Mixed layer depth' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 502439
#Transient thermocline depth
'Transient thermocline depth' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 502440
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 502441
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 502442
#Best lifted index (to 500 hPa)
'Best lifted index (to 500 hPa)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 502443
#Water temperature
'Water temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 502444
#Deviation of sea-elbel from mean
'Deviation of sea-elbel from mean' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 502445
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502446
#salinity
'salinity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 502447
#Density
'Density' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 502448
#Sea Ice Cover ( 0= free, 1=cover)
'Sea Ice Cover ( 0= free, 1=cover)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 502449
#sea Ice Thickness
'sea Ice Thickness' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 502450
#Direction of ice drift
'Direction of ice drift' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 502451
#Speed of ice drift
'Speed of ice drift' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 502452
#U-component of ice drift
'U-component of ice drift' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 502453
#V-component of ice drift
'V-component of ice drift' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 502454
#Ice growth rate
'Ice growth rate' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 502455
#Snow melt
'Snow melt' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 502456
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 502457
#Direction of wind waves
'Direction of wind waves' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 502458
#Significant height of wind waves
'Significant height of wind waves' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 502459
#Mean period of wind waves
'Mean period of wind waves' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 502460
#Mean direction of total swell
'Mean direction of total swell' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 502461
#Significant height of swell waves
'Significant height of swell waves' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 502462
#Swell Mean Period
'Swell Mean Period' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 502465
#Secondary wave direction
'Secondary wave direction' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 502466
#Secondary wave period
'Secondary wave period' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 502467
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 502468
#Net long wave radiation flux (m) (at the surface)
'Net long wave radiation flux (m) (at the surface)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 502469
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 502470
#Net long-wave radiation flux(atmosph.top)
'Net long-wave radiation flux(atmosph.top)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 502471
#Long wave radiation flux
'Long wave radiation flux' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 502472
#Short wave radiation flux
'Short wave radiation flux' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 502473
#Global radiation flux
'Global radiation flux' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 502474
#Radiance (with respect to wave number)
'Radiance (with respect to wave number)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 502475
#Radiance (with respect to wave length)
'Radiance (with respect to wave length)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 502476
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 502477
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 502478
#Wind mixing energy
'Wind mixing energy' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 502479
#Image data
'Image data' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 502480
#Geopotential height
'Geopotential height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502481
#Soil Temperature
'Soil Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 502482
#Snow Depth water equivalent
'Snow Depth water equivalent' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 502483
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 502484
#Total Cloud Cover
'Total Cloud Cover' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 502485
#Total Precipitation (Accumulation)
'Total Precipitation (Accumulation)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 502486
#Boundary Layer Dissipitation
'Boundary Layer Dissipitation' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 502487
#Sensible Heat Net Flux (m)
'Sensible Heat Net Flux (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 502488
#Latent Heat Net Flux (m)
'Latent Heat Net Flux (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 502490
#Evaporation (s)
'Evaporation (s)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 502491
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 502492
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 502493
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 502494
#Brightness Temperature
'Brightness Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 502495
#Water Runoff
'Water Runoff ' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 502496
#Geometric Height
'Geometric Height' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 502497
#Standard devation of height
'Standard devation of height' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 502498
#Standard devation of height
'Standard devation of height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 502499
#Pseudo-adiabatic potential Temperature
'Pseudo-adiabatic potential Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 502500
#Pseudo-adiabatic potential Temperature
'Pseudo-adiabatic potential Temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 502501
#Max Temperature
'Max Temperature ' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 502502
#Min Temperature
'Min Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 502503
#Dew Point Temperature
'Dew Point Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 502504
#Dew point depression(or deficit)
'Dew point depression(or deficit)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 502506
#Radar spectra (2)
'Radar spectra (2)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 502507
#Radar spectra (3)
'Radar spectra (3)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 502508
#Parcel lifted index (to 500 hPa)
'Parcel lifted index (to 500 hPa)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 502509
#Temperature anomaly
'Temperature anomaly' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 502510
#Pressure anomaly
'Pressure anomaly' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 502511
#Geopotential height anomaly
'Geopotential height anomaly' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 502512
#Montgomery stream Function
'Montgomery stream Function' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 502513
#Montgomery stream Function
'Montgomery stream Function' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 502514
#Sigma coordinate vertical velocity
'Sigma coordinate vertical velocity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502515
#Absolute divergence
'Absolute divergence' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 502516
#Vertical u-component shear
'Vertical u-component shear' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 502517
#Vertical v-component shear
'Vertical v-component shear' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 502518
#Direction of current
'Direction of current' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 502519
#Speed of current
'Speed of current' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 502520
#U-component of current
'U-component of current' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 502521
#V-component of current
'V-component of current' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 502522
#Humidity mixing ratio
'Humidity mixing ratio' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 502523
#Vapour pressure
'Vapour pressure' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 502524
#Saturation deficit
'Saturation deficit' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 502525
#Precipitation rate
'Precipitation rate' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 502526
#Thunderstorm probability
'Thunderstorm probability' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 502527
#Convective precipitation (water)
'Convective precipitation (water)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 502528
#Snow fall rate water equivalent
'Snow fall rate water equivalent' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 502529
#Mixed layer depth
'Mixed layer depth' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 502530
#Transient thermocline depth
'Transient thermocline depth' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 502531
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 502532
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 502533
#Best lifted index (to 500 hPa)
'Best lifted index (to 500 hPa)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 502534
#Deviation of sea-elbel from mean
'Deviation of sea-elbel from mean' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 502535
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502536
#Direction of ice drift
'Direction of ice drift' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 502537
#Speed of ice drift
'Speed of ice drift' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 502538
#U-component of ice drift
'U-component of ice drift' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 502539
#V-component of ice drift
'V-component of ice drift' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 502540
#Ice growth rate
'Ice growth rate' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 502542
#Snow melt
'Snow melt' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 99 ;
	}

#paramId: 502545
#Secondary wave direction
'Secondary wave direction' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 502546
#Secondary wave period
'Secondary wave period' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 502547
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 502548
#Net long wave radiation flux (m) (at the surface)
'Net long wave radiation flux (m) (at the surface)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 502549
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 502550
#Net long-wave radiation flux(atmosph.top)
'Net long-wave radiation flux(atmosph.top)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 502551
#Long wave radiation flux
'Long wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 502552
#Short wave radiation flux
'Short wave radiation flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 502553
#Radiance (with respect to wave number)
'Radiance (with respect to wave number)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 502554
#Radiance (with respect to wave length)
'Radiance (with respect to wave length)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 502555
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 502556
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 502557
#Wind mixing energy
'Wind mixing energy' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 502558
#Image data
'Image data' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 502559
#Geopotential height
'Geopotential height' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502560
#Soil Temperature
'Soil Temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 502562
#Potential temperature
'Potential temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 502563
#Potential temperature
'Potential temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 502564
#Wind speed (SP)
'Wind speed (SP)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 32 ;
	}

#paramId: 502565
#Pressure
'Pressure' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 1 ;
	}

#paramId: 502566
#Max 2m Temperature
'Max 2m Temperature ' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 15 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502567
#Min 2m Temperature
'Min 2m Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 16 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502568
#Geopotential
'Geopotential' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 6 ;
	}

#paramId: 502569
#Temperature
'Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 11 ;
	}

#paramId: 502570
#U-Component of Wind
'U-Component of Wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 502571
#V-Component of Wind
'V-Component of Wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 502572
#Specific Humidity
'Specific Humidity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 51 ;
	}

#paramId: 502573
#Pressure (S) (not reduced)
'Pressure (S) (not reduced)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502574
#Vertical Velocity (Pressure) ( omega=dp/dt )
'Vertical Velocity (Pressure) ( omega=dp/dt )' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 39 ;
	}

#paramId: 502575
#vertical vorticity
'vertical vorticity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 502576
#Boundary Layer Dissipitation
'Boundary Layer Dissipitation' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 123 ;
	}

#paramId: 502577
#Sensible Heat Net Flux (m)
'Sensible Heat Net Flux (m)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 122 ;
	}

#paramId: 502578
#Latent Heat Net Flux (m)
'Latent Heat Net Flux (m)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 121 ;
	}

#paramId: 502579
#Pressure Reduced to MSL
'Pressure Reduced to MSL' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 2 ;
	}

#paramId: 502581
#Geopotential height
'Geopotential height' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 7 ;
	}

#paramId: 502582
#Relative Humidity
'Relative Humidity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 52 ;
	}

#paramId: 502583
#U-Component of Wind
'U-Component of Wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502584
#V-Component of Wind
'V-Component of Wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}

#paramId: 502585
#2m Temperature
'2m Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}

#paramId: 502587
#Relative Divergenz
'Relative Divergenz' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 44 ;
	}

#paramId: 502588
#Land Cover (1=land, 0=sea)
'Land Cover (1=land, 0=sea)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 81 ;
	}

#paramId: 502589
#Surface Roughness length Surface Roughness
'Surface Roughness length Surface Roughness' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 83 ;
	}

#paramId: 502590
#Albedo (in short-wave, average)
'Albedo (in short-wave, average)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 84 ;
	}

#paramId: 502591
#Evaporation (s)
'Evaporation (s)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 57 ;
	}

#paramId: 502592
#Convective Cloud Cover
'Convective Cloud Cover' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 502593
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 502594
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 74 ;
	}

#paramId: 502595
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 502596
#Brightness Temperature
'Brightness Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 118 ;
	}

#paramId: 502597
#Plant cover
'Plant cover' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 87 ;
	}

#paramId: 502598
#Water Runoff
'Water Runoff ' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 90 ;
	}

#paramId: 502599
#Total Column Integrated Ozone
'Total Column Integrated Ozone' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 10 ;
	}

#paramId: 502600
#Convective Snowfall water equivalent (s)
'Convective Snowfall water equivalent (s)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 78 ;
	}

#paramId: 502601
#Large-Scale snowfall - water equivalent (Accumulation)
'Large-Scale snowfall - water equivalent (Accumulation)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 79 ;
	}

#paramId: 502602
#Large-Scale Precipitation
'Large-Scale Precipitation ' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 62 ;
	}

#paramId: 502603
#Total Column-Integrated Cloud Water
'Total Column-Integrated Cloud Water' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 502604
#Pressure Tendency
'Pressure Tendency ' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 3 ;
	}

#paramId: 502605
#ICAO Standard Atmosphere reference height
'ICAO Standard Atmosphere reference height' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 5 ;
	}

#paramId: 502606
#Geometric Height
'Geometric Height' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 8 ;
	}

#paramId: 502607
#Standard devation of height
'Standard devation of height' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 9 ;
	}

#paramId: 502608
#Pseudo-adiabatic potential Temperature
'Pseudo-adiabatic potential Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 14 ;
	}

#paramId: 502609
#Max Temperature
'Max Temperature ' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 15 ;
	}

#paramId: 502610
#Min Temperature
'Min Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 16 ;
	}

#paramId: 502611
#Dew Point Temperature
'Dew Point Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 17 ;
	}

#paramId: 502612
#Dew point depression(or deficit)
'Dew point depression(or deficit)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 18 ;
	}

#paramId: 502613
#Lapse rate
'Lapse rate' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 19 ;
	}

#paramId: 502614
#Visibility
'Visibility' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 502615
#Radar spectra (1)
'Radar spectra (1)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 21 ;
	}

#paramId: 502616
#Radar spectra (2)
'Radar spectra (2)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 22 ;
	}

#paramId: 502617
#Radar spectra (3)
'Radar spectra (3)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 23 ;
	}

#paramId: 502618
#Parcel lifted index (to 500 hPa)
'Parcel lifted index (to 500 hPa)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 24 ;
	}

#paramId: 502619
#Temperature anomaly
'Temperature anomaly' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 502620
#Pressure anomaly
'Pressure anomaly' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 26 ;
	}

#paramId: 502621
#Geopotential height anomaly
'Geopotential height anomaly' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 27 ;
	}

#paramId: 502622
#Wave spectra (1)
'Wave spectra (1)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 28 ;
	}

#paramId: 502623
#Wave spectra (2)
'Wave spectra (2)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 29 ;
	}

#paramId: 502624
#Wave spectra (3)
'Wave spectra (3)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 30 ;
	}

#paramId: 502625
#Wind Direction (DD)
'Wind Direction (DD)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 31 ;
	}

#paramId: 502626
#Montgomery stream Function
'Montgomery stream Function' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 502627
#Sigma coordinate vertical velocity
'Sigma coordinate vertical velocity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 38 ;
	}

#paramId: 502628
#Absolute Vorticity
'Absolute Vorticity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 41 ;
	}

#paramId: 502629
#Absolute divergence
'Absolute divergence' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 42 ;
	}

#paramId: 502630
#Vertical u-component shear
'Vertical u-component shear' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 45 ;
	}

#paramId: 502631
#Vertical v-component shear
'Vertical v-component shear' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 502632
#Direction of current
'Direction of current' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 47 ;
	}

#paramId: 502633
#Speed of current
'Speed of current' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 48 ;
	}

#paramId: 502634
#U-component of current
'U-component of current' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 49 ;
	}

#paramId: 502635
#V-component of current
'V-component of current' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 50 ;
	}

#paramId: 502636
#Humidity mixing ratio
'Humidity mixing ratio' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 53 ;
	}

#paramId: 502637
#Precipitable water
'Precipitable water' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 54 ;
	}

#paramId: 502638
#Vapour pressure
'Vapour pressure' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 55 ;
	}

#paramId: 502639
#Saturation deficit
'Saturation deficit' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 56 ;
	}

#paramId: 502640
#Precipitation rate
'Precipitation rate' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 59 ;
	}

#paramId: 502641
#Thunderstorm probability
'Thunderstorm probability' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 60 ;
	}

#paramId: 502642
#Convective precipitation (water)
'Convective precipitation (water)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 63 ;
	}

#paramId: 502643
#Snow fall rate water equivalent
'Snow fall rate water equivalent' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 64 ;
	}

#paramId: 502644
#Mixed layer depth
'Mixed layer depth' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 67 ;
	}

#paramId: 502645
#Transient thermocline depth
'Transient thermocline depth' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 68 ;
	}

#paramId: 502646
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 69 ;
	}

#paramId: 502647
#Main thermocline depth
'Main thermocline depth' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 70 ;
	}

#paramId: 502648
#Best lifted index (to 500 hPa)
'Best lifted index (to 500 hPa)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 502649
#Water temperature
'Water temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 80 ;
	}

#paramId: 502650
#Deviation of sea-elbel from mean
'Deviation of sea-elbel from mean' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 82 ;
	}

#paramId: 502651
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502652
#salinity
'salinity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 88 ;
	}

#paramId: 502653
#Density
'Density' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 89 ;
	}

#paramId: 502654
#Sea Ice Cover ( 0= free, 1=cover)
'Sea Ice Cover ( 0= free, 1=cover)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 91 ;
	}

#paramId: 502655
#sea Ice Thickness
'sea Ice Thickness' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 92 ;
	}

#paramId: 502656
#Direction of ice drift
'Direction of ice drift' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 93 ;
	}

#paramId: 502657
#Speed of ice drift
'Speed of ice drift' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 94 ;
	}

#paramId: 502658
#U-component of ice drift
'U-component of ice drift' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 95 ;
	}

#paramId: 502659
#V-component of ice drift
'V-component of ice drift' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 96 ;
	}

#paramId: 502660
#Ice growth rate
'Ice growth rate' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 97 ;
	}

#paramId: 502662
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 100 ;
	}

#paramId: 502663
#Direction of wind waves
'Direction of wind waves' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 101 ;
	}

#paramId: 502664
#Significant height of wind waves
'Significant height of wind waves' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 102 ;
	}

#paramId: 502665
#Mean period of wind waves
'Mean period of wind waves' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 103 ;
	}

#paramId: 502666
#Mean direction of total swell
'Mean direction of total swell' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 104 ;
	}

#paramId: 502667
#Significant height of swell waves
'Significant height of swell waves' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 105 ;
	}

#paramId: 502668
#Swell Mean Period
'Swell Mean Period' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 106 ;
	}

#paramId: 502671
#Secondary wave direction
'Secondary wave direction' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 109 ;
	}

#paramId: 502672
#Secondary wave period
'Secondary wave period' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 110 ;
	}

#paramId: 502673
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 111 ;
	}

#paramId: 502674
#Net long wave radiation flux (m) (at the surface)
'Net long wave radiation flux (m) (at the surface)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 112 ;
	}

#paramId: 502675
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 113 ;
	}

#paramId: 502676
#Net long-wave radiation flux(atmosph.top)
'Net long-wave radiation flux(atmosph.top)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 114 ;
	}

#paramId: 502677
#Long wave radiation flux
'Long wave radiation flux' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 115 ;
	}

#paramId: 502678
#Short wave radiation flux
'Short wave radiation flux' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 116 ;
	}

#paramId: 502679
#Global radiation flux
'Global radiation flux' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 117 ;
	}

#paramId: 502680
#Radiance (with respect to wave number)
'Radiance (with respect to wave number)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 119 ;
	}

#paramId: 502681
#Radiance (with respect to wave length)
'Radiance (with respect to wave length)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 502682
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 124 ;
	}

#paramId: 502683
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 125 ;
	}

#paramId: 502684
#Wind mixing energy
'Wind mixing energy' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 126 ;
	}

#paramId: 502685
#Image data
'Image data' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 127 ;
	}

#paramId: 502686
#Geopotential height
'Geopotential height' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 7 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 502687
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 86 ;
	}

#paramId: 502688
#Soil Temperature
'Soil Temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 85 ;
	}

#paramId: 502689
#Snow Depth water equivalent
'Snow Depth water equivalent' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 66 ;
	}

#paramId: 502690
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 65 ;
	}

#paramId: 502691
#Total Cloud Cover
'Total Cloud Cover' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 502692
#Total Precipitation (Accumulation)
'Total Precipitation (Accumulation)' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 61 ;
	}

#paramId: 502693
#Potential temperature
'Potential temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 13 ;
	}

#paramId: 502694
#Ice divergence
'Ice divergence' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 502695
#Ice divergence
'Ice divergence' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 502696
#Ice divergence
'Ice divergence' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 98 ;
	}

#paramId: 502697
#Velocity potential
'Velocity potential' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 502750
#Stream function
'Stream function' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 35 ;
	}

#paramId: 502796
#Precipitation
'Precipitation' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 71 ;
	}

#paramId: 502946
#Visibility
'Visibility' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 503049
#Eddy dissipitation rate of TKE
'Eddy dissipitation rate of TKE' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 151 ;
	}

#paramId: 503061
#Downward diffusive short wave radiation flux at surface ( mean over forecast time)
'Downward diffusive short wave radiation flux at surface ( mean over forecast time)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 23 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503062
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'Upward diffusive short wave radiation flux at surface ( mean over forecast time)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 24 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503063
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 124 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503064
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 125 ;
	 indicatorOfTypeOfLevel = 1 ;
	}

#paramId: 503065
#u-momentum flux due to SSO-effects
'u-momentum flux due to SSO-effects' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 231 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 503066
#v-momentum flux due to SSO-effects
'v-momentum flux due to SSO-effects' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 232 ;
	 timeRangeIndicator = 1 ;
	}

#paramId: 503068
#precipitation, qualified,BRD
'precipitation, qualified,BRD' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 72 ;
	}

#paramId: 503069
#precipitation,BRD
'precipitation,BRD' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 73 ;
	}

#paramId: 503070
#precipitation phase,BRD
'precipitation phase,BRD' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 75 ;
	}

#paramId: 503071
#hail flag,BRD
'hail flag,BRD' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 76 ;
	}

#paramId: 503072
#snow rate,BRD
'snow rate,BRD' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 77 ;
	}

#paramId: 503073
#snow rate, qualified,BRD
'snow rate, qualified,BRD' = {
	 table2Version = 204 ;
	 indicatorOfParameter = 46 ;
	}

#paramId: 503076
#Gravity wave dissipation
'Gravity wave dissipation ' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 233 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 503078
#relative humidity over mixed phase
'relative humidity over mixed phase' = {
	 table2Version = 250 ;
	 indicatorOfParameter = 20 ;
	}

#paramId: 503082
#Friction Velocity
'Friction Velocity' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 120 ;
	}

#paramId: 503098
#Vertical Velocity (Geometric) (w)
'Vertical Velocity (Geometric) (w)' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 40 ;
	}

#paramId: 503099
#Fog_fraction
'Fog_fraction' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 138 ;
	}

#paramId: 503100
#accumulated_convective_rain
'accumulated_convective_rain' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 140 ;
	}

#paramId: 503101
#cloud_fraction_below_1000ft
'cloud_fraction_below_1000ft' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 207 ;
	}

#paramId: 503103
#Lowest_cloud_base_height
'Lowest_cloud_base_height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 151 ;
	}

#paramId: 503104
#wet_bulb_freezing_level_ht
'wet_bulb_freezing_level_ht' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 152 ;
	}

#paramId: 503105
#freezing_level_ICAO_height
'freezing_level_ICAO_height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 162 ;
	}

#paramId: 503134
#Downward long-wave radiation flux
'Downward long-wave radiation flux' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 25 ;
	}

#paramId: 503135
#Downward long-wave radiation flux avg
'Downward long-wave radiation flux avg' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 25 ;
	 timeRangeIndicator = 3 ;
	}

#paramId: 503136
#Downward long-wave radiation flux accum
'Downward long-wave radiation flux accum' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 25 ;
	 timeRangeIndicator = 4 ;
	}

#paramId: 503140
#orography
'orography' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 148 ;
	}

#paramId: 503141
#wind_gust_10m
'wind_gust_10m' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 149 ;
	}

#paramId: 503142
#Lightning Potential Index
'Lightning Potential Index' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 503286
#Impervious (paved or sealed) surface fraction
'Impervious (paved or sealed) surface fraction' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 33 ;
	}

#paramId: 503287
#Antropogenic heat flux (e.g. urban heating, traffic)
'Antropogenic heat flux (e.g. urban heating, traffic)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 34 ;
	}

#paramId: 503325
#Lightning Potential Index
'Lightning Potential Index' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 196 ;
	}

#paramId: 503341
#Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)
'Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 35 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503342
#Maximum rotation amplitude (positive or negative)  (over given time interval and column)
'Maximum rotation amplitude (positive or negative)  (over given time interval and column)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 36 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503343
#Maximum updraft track (over given time interval and column)
'Maximum updraft track (over given time interval and column)' = {
	 table2Version = 203 ;
	 indicatorOfParameter = 37 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503344
#Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)
'Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 49 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503345
#Maximum total-column integrated condensed  water (over given time interval)
'Maximum total-column integrated condensed  water (over given time interval)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 48 ;
	 indicatorOfTypeOfLevel = 200 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503346
#Composite reflectivity - observation
'Composite reflectivity - observation' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 235 ;
	}

#paramId: 503347
#Composite reflectivity - forecast (simulation)
'Composite reflectivity - forecast (simulation)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 234 ;
	}

#paramId: 503348
#Maximum of Lightning Potential Index (over given time interval)
'Maximum of Lightning Potential Index (over given time interval)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 196 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503349
#Maximum reflectivity track (over given time interval and entire atmosphere)
'Maximum reflectivity track (over given time interval and entire atmosphere)' = {
	 table2Version = 201 ;
	 indicatorOfParameter = 230 ;
	 indicatorOfTypeOfLevel = 200 ;
	 timeRangeIndicator = 2 ;
	}

#paramId: 503350
#relative vorticity
'relative vorticity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 43 ;
	}

#paramId: 503421
#Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present
'Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 36 ;
	}

#paramId: 503422
#Echotop-height: largest height where radar reflectivity above a threshold is present
'Echotop-height: largest height where radar reflectivity above a threshold is present' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 37 ;
	}

#paramId: 503425
#Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)
'Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)' = {
	 table2Version = 202 ;
	 indicatorOfParameter = 39 ;
	}

